module(..., package.seeall)

-- BELOW is Director code
function new()
	local localGroup = display.newGroup()
-- ABOVE is Director code

-- If you have not yet used Director please check out the tutorial on Techority before continuing.
-------------------------------------------------------------------------
-------------------------------------------------------------------------

require "saveit"
--[[
Saveit is something I quickly put together from Ansca's sample code to allow me to save an
attribute when I update it.
Although data is automatically saved when the user quits the application, in my case I needed more.

My Scenario: Data was loaded on menu page. Data was saved on exit. If I updated attribute X then
returned to the menu page prior to saving it, it would reset to what it was previously saved as when
the app was originally opened.

There are many ways of handling this but I found "Saveit" to be right for me, so I'm sharing it
with you.
--]]

-------------------------------------------------------------------------
-------------------------------------------------------------------------
-------------------------------------------------------------------------
local function resumeStart()
			local path = system.pathForFile( "ourdata.txt", system.DocumentsDirectory )                
				local file = io.open( path, "r" )

				if file then
					print("Loading our data...")
					local contents = file:read( "*a" )
					-- Loads our data
					
					local prevState = explode(", ", contents)

                        _G.onelock = prevState[1]
                        _G.twolock = prevState[2]

					io.close( file )

				else
					_G.onelock = 1
					_G.twolock = 0
				end
			end
			-- Separates the variables into a table
 
local function onSystemEvent( event )
		if( event.type == "applicationExit" ) then              
				local path = system.pathForFile( "ourdata.txt", system.DocumentsDirectory )                
				local file = io.open( path, "w+b" )
				-- Creates the file where we save our data
				
				file:write( _G.onelock ..", ".. _G.twolock)          
				io.close( file )
			end
		end
		-- Saves our data

--[[
Alright, I'm sure this probably seems pretty overwhelming if you haven't played with it before.

Don't panic! You'll understand it very soon. Let's talk about the above code;

1. On line 30 we state the name of our file. When testing, you change it a lot, usually by adding a
number to the end. You can use any title you want.

2. On line 30 "ourdata.txt" MUST MUST MUST be identical to the file name in line 54. If you don't do
this it will NOT work.

3. In this tutorial we are using two attributes/variables. "onelock" and "twolock". We have named them
_G.onelock and _G.twolock because they are GLOBAL. They must be global to work as intended when using
Director. Simply add "_G." and that's done.

4. You will note that these attributes/variables are mentioned three times above;

The first; We list them and assign them a number. Note we start at 1, not 0.

The second; If they don't currently have values it's because it's the first time you've opened the app
and the save file does not yet exist. In this case we say that _G.onelock starts as 1 (level one is
unlocked) and _G.twolock starts as 0 (two is locked).

The third; This is where we make a list to write the file on exit.

5. I have already done it this time but you MUST make sure that you open saveit.lua and check that
the contents of that file matches what we have above.

This is no where near as complex as it sounds - I just want to make sure I am thorough as too much
help is always better than not enough!
--]]

--BELOW THIS LINE IS ANSCA'S SAMPLE CODE (I don't mess with perfection)
-- explode helper function
function explode(div,str)
  if (div=='') then return false end
  local pos,arr = 0,{}
  -- for each divider found
  for st,sp in function() return string.find(str,div,pos,true) end do
    table.insert(arr,string.sub(str,pos,st-1)) -- Attach chars left of current divider
    pos = sp + 1 -- Jump past current divider
  end
  table.insert(arr,string.sub(str,pos)) -- Attach chars right of last divider
  return arr
end
 
local function init()
        -- start and resume from previous state, if any
        resumeStart()   
         
        Runtime:addEventListener( "system", onSystemEvent )     
end
 
 
--start the program
init()
--ABOVE THIS LINE IS ANSCA'S SAMPLE CODE (You don't need to change it, so don't!)

----------------------------------------------------------------------
--								SCENE SETUP							--
----------------------------------------------------------------------
local background = display.newImage ("background.png")
localGroup:insert(background)
-- Sets the background

local leveloneicon = display.newImage ("level1icon.png")
leveloneicon.x = 50
leveloneicon.y = 40
localGroup:insert(leveloneicon)
-- Sets the icon for level one

local function gotoone (event)
director:changeScene("level1")
end
leveloneicon:addEventListener("tap", gotoone)
-- Go to level one when icon is tapped

local function gototwo (event)
director:changeScene("level2")
end
-- Function to go to level two

local function seticontwo (event)
if _G.twolock-0 == 0 then
local leveltwoicon = display.newImage ("level2locked.png")
leveltwoicon.x = 130
leveltwoicon.y = 40
localGroup:insert(leveltwoicon)
elseif _G.twolock-0 == 1 then
local leveltwoicon = display.newImage ("level2icon.png")
leveltwoicon.x = 130
leveltwoicon.y = 40
localGroup:insert(leveltwoicon)
leveltwoicon:addEventListener("tap", gototwo)
end
end
seticontwo()

-- The above checks whether _G.twolock is equal to 0 (locked) or 1 (unlocked) and sets the icon
-- If level two is unlocked the listener will be added to the icon.

-- After checking what you have above matches SAVEIT.LUA, go to LEVEL1.LUA

----------------------------------------------------------------------
----------------------------------------------------------------------
-- BELOW is Director code
	-- MUST return a display.newGroup()
	return localGroup
end
-- ABOVE is Director code
